MouthingResult class

The result of mouthing a word: its IPA, and the SignWriting representation in both FSW and SWU (null when the IPA could not be fully mouthed).

Constructors

MouthingResult({required String ipa, required String? fsw, required String? swu})
const

Properties

fsw String?
final
hashCode int
The hash code for this object.
no setterinherited
ipa String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swu String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited